#
# spec file for package ipp-usb
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         import_path github.com/OpenPrinting/ipp-usb
Name:           ipp-usb
Version:        0.9.29
Release:        1.2
Summary:        HTTP reverse proxy, backed by IPP-over-USB connection to device
License:        BSD-2-Clause
URL:            https://github.com/OpenPrinting/ipp-usb
Source0:        %{name}-%{version}.tar.zst
Source1:        %{name}.service
BuildRequires:  goipp
BuildRequires:  golang-packaging
BuildRequires:  gzip
BuildRequires:  pkgconfig
BuildRequires:  zstd
BuildRequires:  pkgconfig(avahi-client)
BuildRequires:  pkgconfig(avahi-core)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(libusb)
BuildRequires:  pkgconfig(systemd)

%description
IPP-over-USB allows using the IPP protocol, normally designed for network
printers, to be used with USB printers as well.

%prep
%autosetup
%goprep %{import_path}

%build
go build -buildmode=pie -mod=vendor .

%install
install -d %{buildroot}%{_datadir}/%{name}/quirks
install -Dm0755 %{name} %{buildroot}%{_sbindir}/%{name}
install -Dm0644 systemd-udev/71-%{name}.rules %{buildroot}/%{_prefix}/lib/udev/rules.d/71-%{name}.rules
install -Dm0644 %{name}-quirks/* %{buildroot}%{_datadir}/%{name}/quirks/
install -Dm0644 %{name}.conf %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf
install -Dm0644 %{SOURCE1} %{buildroot}%{_prefix}/lib/systemd/system/%{name}.service
install -d %{buildroot}%{_localstatedir}/log/%{name}
install -d %{buildroot}%{_sysconfdir}/%{name}

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%check
#needs a daemon to function

%files
%license LICENSE
%doc README.md
%{_sbindir}/%{name}
%{_prefix}/lib/udev/rules.d/71-%{name}.rules
%{_localstatedir}/log/%{name}
%dir %{_sysconfdir}/%{name}
%config %{_sysconfdir}/%{name}/%{name}.conf
%{_prefix}/lib/systemd/system/%{name}.service
%{_datadir}/%{name}

%changelog
* Fri Feb 28 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 0.9.29:
  * USB: zero-length read logged at Debug level
  * Fixed formatting of debug message
  * Performance tuning after 0-length USB packets reception
  * fixed typo in names of two local variables
  * Fixed crash on ipp-usb status
  * Added tcp port info to status output
  * Applied changes for pull request
  * Fixed ipp-usb status formatting for small port numbers (<10000)
  * Fixed crash with blacklisted devices
  * USB serial number and vendor/device ID exposed via TXT record
  * ipp-usb status: if HTTP port is not available, print "-" instead of "0"
  * Newly added usb_SER and usb_HWID TXT records documented on the man page
  * Quirks handling refactored. Quirks tests updated.
  * Low-level USB I/O refactored to be cancelable via context.Context
  * Added comprehensive test of quirks value parsers
  * Fixed go 1.11 build
  * avoided code duplication in decoding libusb_transfer results
  * Refactiring: UsbIO renamed to UsbEIO, for consistency with other error
    codes
  * Refactoring: use context.Context to specify low-level USB I/O timeout
  * Don't start USB low-level I/O operation, if context.Context already
    expired
  * Removed unused function
  * Device initialization timeout handling revisited
  * Fixed premature context.Context cancellation for HTTP requests with
    timeout
  * Added alternative syntax for delays in the quirks
  * ipp-usb-quirks/README updated
  * Device init timeout was mistakenly left enabled after the initialization
  * Added 'init-timeout' quirk
  * Removed unneeded debug print, occasionally leaked to the repo
  * Minor tweak of log message
  * Fixed possibility to cancel response body fetching before completion
  * Fixed handling of errors returned by libusb_submit_transfer()
  * Quirks logistics down to the UsbInterface structure
  * Added 'zlp-send'
  * Added 'zlp-recv-hack' quirk
  * More testing of quirks
  * Fixed few typos in the man page
  * Added 'init-retry-partial' quirk
  * Logging tweaked a bit
  * Fix init-retry-partial when zlp-recv-hack triggers during HTTP header
    reception
  * HP quirks updated
  * Removed println line, leaked by mistake
  * Fixed wildcard, used in quirks to match HP Color LaserJet Flow
- update to 0.9.28:
  * remove debian directory
- switch to obs_scm, so we can save on disk space in the long run
- remove go vendor workaround, as upstream fixed the issue
- remove download_files service, as it was never needed
* Thu Jul 25 2024 Richard Rahl <rrahl0@opensuse.org>
- update to version 0.9.27:
  * HTTP port allocation takes into consideration /var/ipp-usb/dev/*
  * If quirk's init-delay is high enough, initialization always times out
  * Device USB port added to logged device info
  * Pantum BM5100ADN series quirks: disable-fax = true
  * inifile.go: removed excessive break statements
  * UID authentication instrumented
  * auth: fixed possible race in access to UID lookup cache
  * auth: don't attempt to resolve UID, if UID is not known
  * auth: don't try to obtain client UID, if we don't actually use it
  * TCPClientUID better instrumented
  * uid auth: fixed to run on systems with disabled IPv6 support
- fix service file (missing Install section)
* Thu Mar 14 2024 Richard Rahl <rrahl0@proton.me>
- initial packaging
